const db = require('../utils/db')
const config = require('../utils/config')
const dateHelper = require('../utils/dateHelper')
const messages = require('../utils/messages.json')
const promise = require('bluebird')
const FCM = require('fcm-node')
let FCM_SERVER_KEY = config.FCMApiKeyTekoto
let fcm = new FCM(FCM_SERVER_KEY)
const moment = require('moment')

class NotificationHelper {
  // insertNotification(notification_text, customer_id, notify_type, bold_text, language) {
  //   let data = {
  //     customer_id: customer_id,
  //     notify_type: notify_type,
  //     is_read: 0,
  //     message: [language][notification_text],
  //     bold_text: messages[language][bold_text],
  //     created_date: dateHelper.getCurrentTimeStamp(),
  //     modified_date: dateHelper.getCurrentTimeStamp()
  //   }

  //   db.insert('admin_sent_notifications', data);
  // }  

  insertNotification(notify_id, title, text, sender_id, receiver_id, notify_type, unique_id, language, notification_table, is_from_customer, is_from_admin, date) {
    let data = {
      notify_id: notify_id,
      title: title,
      text: text,
      sender_id: sender_id,
      receiver_id: receiver_id,
      notify_type: notify_type,
      unique_id: unique_id,
      is_read: 0,
      created_date: dateHelper.getCurrentTimeStamp(),
      modified_date: dateHelper.getCurrentTimeStamp(),
      is_deleted: 0,
      is_from_customer: is_from_customer,
      is_from_admin: is_from_admin
    }
    db.insert(notification_table, data)
    return data
  }

  async sendNotification(data, notification_table, notification_id, device_table, user_id_column_name, user_type) {
    let unread_notification_count = 0, unread_chat_message_count = 0,
      unread_notifications = await db.select(notification_table, ` COUNT(${notification_id}) as unread_count`, ` receiver_id = ${data.receiver_id} AND is_read = 0`)
    unread_notification_count = Number(unread_notifications[0].unread_count)
    let chat_user_id = await db.select('chat_user', `chat_user_id`, ` user_type =${user_type} AND user_id = ${data.receiver_id}`)
    if (chat_user_id.length > 0) {
      let unread_chat_messages = await db.select('chat', ` COUNT(chat) as unread_count`, ` receiver_id = ${chat_user_id[0].chat_user_id} AND is_read = 0`)
      unread_chat_message_count = Number(unread_chat_messages[0].unread_count)
    }
    let count = unread_notification_count + unread_chat_message_count  // badge count
    let device_data = await db.select(device_table, `device_token, device_type`, ` ${user_id_column_name} = ${data.receiver_id} AND allow_notification = 1`)
    let android_device_token = [], ios_device_token = []
    for (let d of device_data) {
      if (d.device_type == 1) {
        android_device_token.push(d.device_token)
      } else {
        ios_device_token.push(d.device_token)
      }
    }
    if (notification_table == 'customer_notifications') {
      FCM_SERVER_KEY = config.FCMApiKeyTekoto
    } else if (notification_table == 'service_provider_notifications') {
      FCM_SERVER_KEY = config.FCMApiKeyTekotoJobs
    }
    if (android_device_token.length > 0) {
      this.buildFCM(data.title, data.text, data, count, 1, android_device_token, FCM_SERVER_KEY)
    }
    if (ios_device_token.length > 0) {
      this.buildFCM(data.title, data.text, data, count, 0, ios_device_token, FCM_SERVER_KEY)
    }
  }

  buildFCM(title, body, data, count, device_type, device_token, FCM_SERVER_KEY) {
    let payload = {}
    payload.priority = 'high'
    payload.registration_ids = device_token

    data.sound = 'default'
    data.badge = count
    if (device_type == 0) {
      payload.notification = {}
      payload.notification.title = title
      payload.notification.body = body
      for (let key in data) {
        payload.notification[key] = data[key]
      }
      payload.notification.badge = data.badge
    } else if (device_type == 1) {
      payload.data = data
      payload.data.priority = 'high'
      payload.data.show_in_foreground = 'true'
      payload.notification = {}
      payload.notification = data
      payload.notification.priority = 'high'
      payload.notification.show_in_foreground = 'true'
    }
    console.log("=======Payload=======", payload)
    this.sendFCM(payload, FCM_SERVER_KEY)
  }

  sendFCM(payload, FCM_SERVER_KEY) {
    fcm = new FCM(FCM_SERVER_KEY)
    fcm.send(payload, (err, response) => {
      if (err) {
        console.log('====================fcm error ::', err)
      } else {
        console.log('================Notification Sent')
        console.log(response)
      }
    })
  }

  // sendNotification(data) {
  //   let count
  //   db.select('admin_message_customer_relation', 'COUNT(customer_id) as unread_count', ` customer_id = '${data.customer_id}' AND is_read = 0`)
  //     .then((result) => {
  //       count = result[0].unread_count
  //       return db.select('customer_device_relation', 'device_token, device_type', ` customer_id = '${data.customer_id}' AND allow_notification = 1`)
  //     })
  //     .then((result) => {
  //       let android_device_token = []
  //       let ios_device_token = []
  //       for (let r of result) {
  //         if (r.device_type == 1) {
  //           android_device_token.push(r.device_token)
  //         } else {
  //           ios_device_token.push(r.device_token)
  //         }
  //       }
  //       if (android_device_token.length > 0) {
  //         this.buildFCM(data.bold_text, data.notification_text, data, count, 1, android_device_token)
  //       }
  //       if (ios_device_token.length > 0) {
  //         this.buildFCM(data.bold_text, data.notification_text, data, count, 0, ios_device_token)
  //       }
  //     })
  //     .catch((error) => {
  //       console.log(error)
  //     })
  // }

  sendNotificationToServiceProvider(data) {
    let count
    db.select('admin_message_customer_relation', 'COUNT(customer_id) as unread_count', ` customer_id = '${data.customer_id}' AND is_read = 0`)
      .then((result) => {
        count = result[0].unread_count
        return db.select('customer_device_relation', 'device_token, device_type', ` customer_id = '${data.customer_id}' AND allow_notification = 1`)
      })
      .then((result) => {
        let android_device_token = []
        let ios_device_token = []
        for (let r of result) {
          if (r.device_type == 1) {
            android_device_token.push(r.device_token)
          } else {
            ios_device_token.push(r.device_token)
          }
        }
        if (android_device_token.length > 0) {
          this.buildFCM(data.bold_text, data.notification_text, data, count, 1, android_device_token)
        }
        if (ios_device_token.length > 0) {
          this.buildFCM(data.bold_text, data.notification_text, data, count, 0, ios_device_token)
        }
      })
      .catch((error) => {
        console.log(error)
      })
  }

  updateIsRead(body) {
    let data = {
      is_read: 1
    }
    return db.update('admin_message_customer_relation', `customer_id = '${body.customer_id}'`, data);
  }

  async readNotification(admin_id) {
    const data = {
      is_read: 1,
      modified_date: dateHelper.getCurrentTimeStamp()
    }
    await db.update('admin_notifications', `receiver_id = ${admin_id}`, data);
    return true
  }
}

module.exports = new NotificationHelper()
