const promise = require('bluebird')
const db = require('../../utils/db')
const config = require('../../utils/config')
const VideoHelper = require('./VideoHelper')


class RecipeHelper {

    async addRecipe(body) {
        try {
            let requestData = {};
            let image = body.image ? body.image : '';
            let ingredients = body.ingredients ? body.ingredients : '';
            let steps = body.steps ? body.steps : '';
            let video = body.video ? body.video : '';

            requestData['chef_id'] = body.chef_id;
            requestData['category_id'] = body.category_id;
            requestData['name'] = body.name;
            requestData['cooking_time'] = body.cooking_time;
            requestData['food_type'] = body.food_type;
            requestData['recipe_type'] = body.recipe_type;
            requestData['calorie'] = body.calorie;

            if (image) {
                requestData['image'] = image;
            }
            if (ingredients) {
                requestData['ingredients'] = ingredients;
            }
            if (steps) {
                requestData['steps'] = steps;
            }
            if (video) {
                requestData['video'] = video;
            }

            await db.insert('recipe', requestData)

            let data = {};
            return { data };
        } catch (error) {
            return promise.reject(error)
        }
    }

    async addMeal(body) {
        try {
            let requestData = {
                user_id: body.user_id,
                recipe_id: body.recipe_id,
                date: body.date, // Date formate should be yyyy-mm-dd
                meal_type: body.meal_type, // breakfast, lunch, dinner	
            };

            await db.insert('meal', requestData)

            let data = {};
            return { data };
        } catch (error) {
            return promise.reject(error)
        }
    }

    async getMeal(body) {
        try {
            let selectParams = '*';
            let result = await db.select('payment_option', selectParams, '');

            let data = {};
            await result.forEach(function (row) {
                if (row.name == 'PayTm') {
                    data['paytm'] = row;
                }
                if (row.name == 'FlutterWave') {
                    data['flutterwave'] = row;
                }
                if (row.name == 'Razorpay') {
                    data['razorpay'] = row;
                }
                if (row.name == 'Paypal') {
                    data['paypal'] = row;
                }
                if (row.name == 'InApp Purchage') {
                    data['inapppurchage'] = row;
                }
            });

            return { data };
        } catch (error) {
            return promise.reject(error)
        }
    }
}

module.exports = new RecipeHelper()