const db = require('../../utils/db')
const promise = require('bluebird')
const joi = require('joi')
const joiValidator = require('../../utils/joiValidator')

/**
 * This HomeValidator class contains car brand model and type add edit list related API's validation.
 */

class HomeValidator {
    async getFavoritesRecipeValidator(body) {
        try {
            let schema = joi.object().keys({
                user_id: joi.number().integer().required(),
            })
            await joiValidator.validateJoiSchema(body, schema);
        } catch (error) {
            return promise.reject(error)
        }
    }

    async getMealValidator(body) {
        try {
            let schema = joi.object().keys({
                user_id: joi.number().integer().required(),
                date: joi.string().required(),
            })
            await joiValidator.validateJoiSchema(body, schema);
        } catch (error) {
            return promise.reject(error)
        }
    }

    async getRecipeByChefIdValidator(body) {
        try {
            let schema = joi.object().keys({
                chef_id: joi.number().integer().required(),
            })
            await joiValidator.validateJoiSchema(body, schema);
        } catch (error) {
            return promise.reject(error)
        }
    }

    async getRelatedRecipeValidator(body) {
        try {
            let schema = joi.object().keys({
                category_id: joi.number().integer().required(),
                user_id: joi.number().integer().optional()
            })
            await joiValidator.validateJoiSchema(body, schema);
        } catch (error) {
            return promise.reject(error)
        }
    }


    async getChefByIdValidator(body) {
        try {
            let schema = joi.object().keys({
                chef_id: joi.number().integer().required(),
            })
            await joiValidator.validateJoiSchema(body, schema);
        } catch (error) {
            return promise.reject(error)
        }
    }

    async searchRecipeValidator(body) {
        try {
            let schema = joi.object().keys({
                name: joi.string().required(),
                user_id: joi.number().integer().optional()
            })
            await joiValidator.validateJoiSchema(body, schema);
        } catch (error) {
            return promise.reject(error)
        }
    }
    async getComment(body) {
        try {
            let schema = joi.object().keys({
                recipe_id: joi.string().required(),
                user_id: joi.number().integer().optional()
            })
            await joiValidator.validateJoiSchema(body, schema);
        } catch (error) {
            return promise.reject(error)
        }
    }



}

module.exports = new HomeValidator()