const express = require('express')
const router = express.Router()
const multer = require('multer')

const headerValidator = require('../api/utils/headersValidator')
const Category = require('../api/v1/controllers/Category')
const Setting = require('../api/v1/controllers/Setting')
const User = require('../api/v1/controllers/User')
const Common = require('../api/v1/controllers/Common')
const Home = require('../api/v1/controllers/Home')
const Recipe = require('../api/v1/controllers/Recipe')
const config = require('../api/utils/config')

var storage = multer.diskStorage({
    destination: function (req, file, cb) {
        if (file.fieldname == 'image') {
            const image_path = config.USER_BASE_PATH + 'user/';
            cb(null, image_path);
        }

        if (file.fieldname == 'recipe_file') {
            const image_path = config.USER_BASE_PATH + 'recipe/';
            cb(null, image_path);
        }
    },
    filename: function (req, file, cb) {
        cb(null, Date.now() + '-' + file.originalname);
    }
});


//Non authentication
router.post('/get_category', headerValidator.nonAuthValidation, Category.getCategoryList)
router.post('/general_setting', headerValidator.nonAuthValidation, Setting.getSettingList)

router.post('/login', headerValidator.nonAuthValidation, User.login)
router.post('/register', headerValidator.nonAuthValidation, User.register)
router.post('/get_profile', headerValidator.nonAuthValidation, User.getUserProfile)
router.post('/update_profile', headerValidator.nonAuthValidation, User.updateProfile)
router.post('/become_chef', headerValidator.nonAuthValidation, User.becomeChef)
router.post('/image_upload', multer({ storage: storage }).single("image"), User.imageUpload)

router.post('/media_upload', multer({ storage: storage }).single("recipe_file"), User.mediaUpload)

router.post('/get_payment_option', headerValidator.nonAuthValidation, Common.getPaymentOption)
router.post('/get_payment_token', headerValidator.nonAuthValidation, Common.getPaymentToken)
router.post('/add_remove_favorites', headerValidator.nonAuthValidation, Common.addRemoveFavorites)
router.post('/add_comment', headerValidator.nonAuthValidation, Common.addComment)
router.post('/add_rating', headerValidator.nonAuthValidation, Common.addRating)

//Recipe
router.post('/add_meal', headerValidator.nonAuthValidation, Recipe.addMeal)
router.post('/add_recipe', multer({ storage: storage }).single("image"), Recipe.addRecipe)

router.post('/get_meal', headerValidator.nonAuthValidation, Home.getMeal)
router.post('/get_chef', headerValidator.nonAuthValidation, Home.getChef)
router.post('/get_chef_by_id', headerValidator.nonAuthValidation, Home.getChefById)
router.post('/get_recipe_by_chef_id', headerValidator.nonAuthValidation, Home.getRecipeByChefId)
router.post('/get_favorites_recipe', headerValidator.nonAuthValidation, Home.getFavoritesRecipe)
router.post('/get_recipe_video', headerValidator.nonAuthValidation, Home.getRecipeVideo)
router.post('/search_recipe', headerValidator.nonAuthValidation, Home.searchRecipe)
router.post('/get_related_recipe', headerValidator.nonAuthValidation, Home.getRelatedRecipe)
router.post('/get_comment', headerValidator.nonAuthValidation, Home.getComment)


router.post('/banner_recipe', headerValidator.nonAuthValidation, Home.bannerRecipe)
router.post('/best_recipe', headerValidator.nonAuthValidation, Home.bestRecipe)
router.post('/trending_recipe', headerValidator.nonAuthValidation, Home.trendingRecipe)

module.exports = router